import React, { useState, useEffect } from 'react';
import { useTransition, animated } from 'react-spring';
import {
	ComponentContainer,
	PageComponent,
	PageContainer,
} from './OnePageView';

export default function TwoPagesView(props) {
	let { src, currIndex, flagToReverse } = props;
	const [pagesToshow, setPagesToShow] = useState([
		{
			src: '',
			alt: '',
			thumbnail: '',
		},
		{
			src: '',
			alt: '',
			thumbnail: '',
		},
	]);

	const transitionFirst = useTransition(pagesToshow[0], (item) => item.src, {
        from: {opacity: 1, transform: flagToReverse? "translate3d(-50%, 0, 0)": "translate3d(100%, 0, 0)"},
        enter: { opacity: 1, transform: "translate3d(0%, 0, 0)" },
        leave: { opacity: 0, transform: flagToReverse? "translate3d(100%, 0, 0)": "translate3d(-50%, 0, 0)"},
	});

	const transitionSecond = useTransition(pagesToshow[1], (item) => item.src, {
        from: {opacity: 1, transform: flagToReverse? "translate3d(0%, 0, 0)": "translate3d(150%, 0, 0)"},
        enter: { opacity: 1, transform: "translate3d(50%, 0, 0)" },
        leave: { opacity: 0, transform: flagToReverse? "translate3d(150%, 0, 0)": "translate3d(0%, 0, 0)"},
	});

	useEffect(() => {
		const shouldShowPage = (pageIndex) => {
			return src.length > 0 && pageIndex <= src.length - 1;
		};

		const newCurrIndex = currIndex % 2 === 0 ? currIndex : currIndex - 1;

		const shouldShowFirstPage = shouldShowPage(newCurrIndex);
		if (shouldShowFirstPage) {
			const shouldShowSecondPage = shouldShowPage(newCurrIndex + 1);
			setPagesToShow([
				src[newCurrIndex],
				shouldShowSecondPage
					? src[newCurrIndex + 1]
					: {
						src: '',
						alt: '',
						thumbnail: '',
					},
			]);
		}
	}, [currIndex, src]);

	return (
		<ComponentContainer>
			<PageContainer>
				{transitionFirst.map(({ item, key, props }) => {
					return (
						item && (
							<animated.div style={{ ...props }} key={key}>
								<PageComponent width={'50%'} src={item.src} />
							</animated.div>
						)
					);
				})}

				{transitionSecond.map(({ item, key, props }) => {
					return (
						item && (
							<animated.div
								style={{
									...props,
									transformOrigin: 'left center',
								}}
								key={key}
							>
								<PageComponent width={'50%'} src={item.src} />
							</animated.div>
						)
					);
				})}
			</PageContainer>
		</ComponentContainer>
	);
}

